from setuptools import setup

setup(
    name='pianist',
    version='0.0.1',
    description='',
    long_description='Orchestration',
    long_description_content_type='text/plain',
    url='https://argodis.de',
    author='Argodis GmbH',
    author_email='info@argodis.de',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)